#!/usr/bin/env node

const program = require('commander')
const CustomerFinder = require('./lib/CustomerFinder.js')
const CustomerListFromURL = require('./lib/CustomerListFromURL.js')

program
  .version('0.0.1')
  .option('--customers [url]', 'URL for customers list.', 'https://s3.amazonaws.com/intercom-take-home-test/customers.txt')
  .option('--home [home]', '"Home" location - distances to customers will be calculated against it. Please prepend negative values with space, like so: --home " -1,2"', '-6.257664, 53.339428')
  .option('--no-orm', 'Disables fetching distance via OpenRouteMap.')
  .option('--direct-routes', 'Fall back to simple calculation if ORM tells there are no routes.')
  .option('-d, --distance [meters]', 'Maximum exclusive distance in meters', 100000)
  .parse(process.argv)

const customerListFromURL = new CustomerListFromURL(program.customers)
const customerFinder = new CustomerFinder(customerListFromURL, program.home.split(','), { noORM: !program.orm, fallbackOnInfinity: program.directRoutes })

console.log('Processing...')
customerFinder.findNearestCustomers(program.distance).then(customers => {
  console.log('Fitting candidates for invitation:')
  customers.sort((a, b) => a.user_id - b.user_id).forEach(customer => {
    console.log('- ' + customer.name + ' (id: ' + customer.user_id + ')')
  })
})
