const rp = require('request-promise-native')

class CustomerListFromURL {
  constructor (url) {
    this._url = url
  }

  /**
   * internal function that actually fetches data
   * @returns {Promise<Response>} request-promise promise
   */
  _fetch () {
    return rp(this._url)
  }

  /**
   * fetches list and processes it into usable JS array
   * @returns {Customer[]} list of customers
   */
  getList () {
    return this._fetch()
    // The data in supplied URL isn't exactly JSON array, instead a list of JSON objects separated by newlines.
      .then((response) => response
        .split('\n') // splitting by newlines
        .map(_ => _.trim()) // trimming strings
        .filter(_ => _) // filter out falsy items (undefineds, empty strings)
            .map(_ => {
              try {
                return JSON.parse(_)
              } catch(e) {
                console.error('----')
                console.error('[WARN] Failed parsing customer line, ignoring...')
                console.error('Line was: <BOL>' + _ + '<EOL>')
                console.error(e.message)
                return undefined
              }
            })
            .filter(_ => _) // filter out faulty items
      )
  }
}

module.exports = CustomerListFromURL
